@@ -26,6 +26,34 @@ class PostgresClient(AbstractClient):
     _service = 'postgres'
 
 
+    def AddDBInstanceToReadOnlyGroup(self, request):
+        """本接口（AddDBInstanceToReadOnlyGroup）用于添加只读实例到只读组
+
+        :param request: Request instance for AddDBInstanceToReadOnlyGroup.
+        :type request: :class:`tencentcloud.postgres.v20170312.models.AddDBInstanceToReadOnlyGroupRequest`
+        :rtype: :class:`tencentcloud.postgres.v20170312.models.AddDBInstanceToReadOnlyGroupResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("AddDBInstanceToReadOnlyGroup", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.AddDBInstanceToReadOnlyGroupResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def CloseDBExtranetAccess(self, request):
         """本接口（CloseDBExtranetAccess）用于关闭实例外网链接。
 
@@ -110,6 +138,62 @@ class PostgresClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def CreateReadOnlyDBInstance(self, request):
+        """本接口(CreateReadOnlyDBInstance)用于创建只读实例
+
+        :param request: Request instance for CreateReadOnlyDBInstance.
+        :type request: :class:`tencentcloud.postgres.v20170312.models.CreateReadOnlyDBInstanceRequest`
+        :rtype: :class:`tencentcloud.postgres.v20170312.models.CreateReadOnlyDBInstanceResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("CreateReadOnlyDBInstance", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.CreateReadOnlyDBInstanceResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def CreateReadOnlyGroup(self, request):
+        """本接口（CreateReadOnlyGroup）用于创建只读组
+
+        :param request: Request instance for CreateReadOnlyGroup.
+        :type request: :class:`tencentcloud.postgres.v20170312.models.CreateReadOnlyGroupRequest`
+        :rtype: :class:`tencentcloud.postgres.v20170312.models.CreateReadOnlyGroupResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("CreateReadOnlyGroup", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.CreateReadOnlyGroupResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def CreateServerlessDBInstance(self, request):
         """本接口 (CreateServerlessDBInstance) 用于创建一个ServerlessDB实例，创建成功返回实例ID。
 
@@ -138,6 +222,34 @@ class PostgresClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DeleteReadOnlyGroup(self, request):
+        """本接口(DeleteReadOnlyGroup)用于删除指定的只读组
+
+        :param request: Request instance for DeleteReadOnlyGroup.
+        :type request: :class:`tencentcloud.postgres.v20170312.models.DeleteReadOnlyGroupRequest`
+        :rtype: :class:`tencentcloud.postgres.v20170312.models.DeleteReadOnlyGroupResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DeleteReadOnlyGroup", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DeleteReadOnlyGroupResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DeleteServerlessDBInstance(self, request):
         """本接口 (DeleteServerlessDBInstance) 用于删除一个ServerlessDB实例。
 
@@ -446,6 +558,34 @@ class PostgresClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DescribeReadOnlyGroups(self, request):
+        """本接口(DescribeReadOnlyGroups)用于查询用户输入指定实例的只读组
+
+        :param request: Request instance for DescribeReadOnlyGroups.
+        :type request: :class:`tencentcloud.postgres.v20170312.models.DescribeReadOnlyGroupsRequest`
+        :rtype: :class:`tencentcloud.postgres.v20170312.models.DescribeReadOnlyGroupsResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DescribeReadOnlyGroups", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribeReadOnlyGroupsResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DescribeRegions(self, request):
         """本接口 (DescribeRegions) 用于查询售卖地域信息。
 
@@ -531,7 +671,7 @@ class PostgresClient(AbstractClient):
 
 
     def DestroyDBInstance(self, request):
-        """本接口 (DestroyDBInstance) 用于销毁指定DBInstanceId对应的实例。
+        """本接口 (DestroyDBInstance) 用于彻底下线指定DBInstanceId对应的实例，下线后实例数据将彻底删除，无法找回，只能下线隔离中的实例。
 
         :param request: Request instance for DestroyDBInstance.
         :type request: :class:`tencentcloud.postgres.v20170312.models.DestroyDBInstanceRequest`
@@ -558,6 +698,34 @@ class PostgresClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DisIsolateDBInstances(self, request):
+        """本接口（DisIsolateDBInstances）用于解隔离实例
+
+        :param request: Request instance for DisIsolateDBInstances.
+        :type request: :class:`tencentcloud.postgres.v20170312.models.DisIsolateDBInstancesRequest`
+        :rtype: :class:`tencentcloud.postgres.v20170312.models.DisIsolateDBInstancesResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DisIsolateDBInstances", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DisIsolateDBInstancesResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def InitDBInstances(self, request):
         """本接口 (InitDBInstances) 用于初始化云数据库PostgreSQL实例。
 
@@ -670,6 +838,34 @@ class PostgresClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def IsolateDBInstances(self, request):
+        """本接口（IsolateDBInstances）用于隔离实例
+
+        :param request: Request instance for IsolateDBInstances.
+        :type request: :class:`tencentcloud.postgres.v20170312.models.IsolateDBInstancesRequest`
+        :rtype: :class:`tencentcloud.postgres.v20170312.models.IsolateDBInstancesResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("IsolateDBInstances", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.IsolateDBInstancesResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def ModifyAccountRemark(self, request):
         """本接口（ModifyAccountRemark）用于修改帐号备注。
 
@@ -726,6 +922,34 @@ class PostgresClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def ModifyDBInstanceReadOnlyGroup(self, request):
+        """本接口（ModifyDBInstanceReadOnlyGroup）用于修改实例所属的只读组
+
+        :param request: Request instance for ModifyDBInstanceReadOnlyGroup.
+        :type request: :class:`tencentcloud.postgres.v20170312.models.ModifyDBInstanceReadOnlyGroupRequest`
+        :rtype: :class:`tencentcloud.postgres.v20170312.models.ModifyDBInstanceReadOnlyGroupResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("ModifyDBInstanceReadOnlyGroup", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.ModifyDBInstanceReadOnlyGroupResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def ModifyDBInstancesProject(self, request):
         """本接口（ModifyDBInstancesProject）用于将实例转至其他项目。
 
@@ -754,6 +978,34 @@ class PostgresClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def ModifyReadOnlyGroupConfig(self, request):
+        """本接口(ModifyReadOnlyGroupConfig)用于更新只读组配置信息
+
+        :param request: Request instance for ModifyReadOnlyGroupConfig.
+        :type request: :class:`tencentcloud.postgres.v20170312.models.ModifyReadOnlyGroupConfigRequest`
+        :rtype: :class:`tencentcloud.postgres.v20170312.models.ModifyReadOnlyGroupConfigResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("ModifyReadOnlyGroupConfig", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.ModifyReadOnlyGroupConfigResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def OpenDBExtranetAccess(self, request):
         """本接口（OpenDBExtranetAccess）用于开通外网。
 
@@ -810,6 +1062,62 @@ class PostgresClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def RebalanceReadOnlyGroup(self, request):
+        """本接口(RebalanceReadOnlyGroup)用于重新均衡 RO 组内实例的负载。注意，RO 组内 RO 实例会有一次数据库连接瞬断，请确保应用程序能重连数据库，谨慎操作。
+
+        :param request: Request instance for RebalanceReadOnlyGroup.
+        :type request: :class:`tencentcloud.postgres.v20170312.models.RebalanceReadOnlyGroupRequest`
+        :rtype: :class:`tencentcloud.postgres.v20170312.models.RebalanceReadOnlyGroupResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("RebalanceReadOnlyGroup", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.RebalanceReadOnlyGroupResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def RemoveDBInstanceFromReadOnlyGroup(self, request):
+        """本接口（RemoveDBInstanceFromReadOnlyGroup）用户将只读实例从只读组中移除
+
+        :param request: Request instance for RemoveDBInstanceFromReadOnlyGroup.
+        :type request: :class:`tencentcloud.postgres.v20170312.models.RemoveDBInstanceFromReadOnlyGroupRequest`
+        :rtype: :class:`tencentcloud.postgres.v20170312.models.RemoveDBInstanceFromReadOnlyGroupResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("RemoveDBInstanceFromReadOnlyGroup", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.RemoveDBInstanceFromReadOnlyGroupResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def RenewInstance(self, request):
         """本接口（RenewInstance）用于续费实例。
 
